<?php
// Register Heading Widget
kng_add_custom_widget(
    array(
        'name'       => 'kng_heading',
        'title'      => esc_html__( 'KNG Heading', 'cetara' ),
        'icon'       => 'eicon-t-letter',
        'categories' => array('kngtheme-core'),
        'scripts'    => array(
            'kng-animation'
        ),
        'params' => array(
            'sections' => array(
                array(
                    'name' => 'title_section',
                    'label' => esc_html__('Title', 'cetara' ),
                    'tab' => 'content',
                    'controls' => array(
                        array(
                            'name' => 'text_align',
                            'label' => esc_html__('Alignment', 'cetara' ),
                            'type' => 'choose',
                            'control_type' => 'responsive',
                            'options' => cetara_text_align_opts(),
                            'selectors' => [
                                '{{WRAPPER}} .kng-heading-wrap' => 'text-align: {{VALUE}};',
                            ],
                        ),
                        array(
                            'name' => 'title',
                            'label' => esc_html__('Title', 'cetara' ),
                            'type' => 'textarea',
                            'label_block' => true,
                        ),
                        array(
                            'name' => 'title_tag',
                            'label' => esc_html__('Heading HTML Tag', 'cetara' ),
                            'type' => 'select',
                            'options' => [
                                'h1' => 'H1',
                                'h2' => 'H2',
                                'h3' => 'H3',
                                'h4' => 'H4',
                                'h5' => 'H5',
                                'h6' => 'H6',
                                'div' => 'div',
                                'span' => 'span',
                                'p' => 'p',
                            ],
                            'default' => 'h3',
                        ),
                        array(
                            'name'         => 'title_break_line',
                            'label'        => esc_html__( 'Remove Title Break Line', 'cetara' ),
                            'type'         => 'select',
                            'default'      => '',
                            'control_type' => 'responsive',
                            'options' => [
                                '' => esc_html__('No', 'cetara' ),
                                'none' => esc_html__('Yes', 'cetara' )
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .kng-heading-wrap .item--title br' => 'display: {{VALUE}};',
                            ],
                        ),
                        array(
                            'name' => 'title_color',
                            'label' => esc_html__('Title Color', 'cetara' ),
                            'type' => 'color',
                            'selectors' => [
                                '{{WRAPPER}} .kng-heading-wrap .item--title' => 'color: {{VALUE}};',
                            ],
                        ),
                        array(
                            'name' => 'title_typography',
                            'label' => esc_html__('Title Typography', 'cetara' ),
                            'type' => \Elementor\Group_Control_Typography::get_type(),
                            'control_type' => 'group',
                            'selector' => '{{WRAPPER}} .kng-heading-wrap .item--title',
                        ),
                        array(
                            'name' => 'title_space_bottom',
                            'label' => esc_html__('Bottom Spacer', 'cetara' ),
                            'type' => 'slider',
                            'control_type' => 'responsive',
                            'size_units' => [ 'px' ],
                            'default' => [
                                'size' => 0,
                            ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 300,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .kng-heading-wrap .item--title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name' => 'style',
                            'label' => esc_html__('Style', 'cetara' ),
                            'type' => 'select',
                            'options' => [
                                'st-default' => 'Default',
                            ],
                            'default' => 'st-default',
                        ),
                        array(
                            'name' => 'kng_animate',
                            'label' => esc_html__('Case Animate', 'cetara' ),
                            'type' => 'select',
                            'options' => cetara_animate_case(),
                            'default' => '',
                        ),
                        array(
                            'name' => 'kng_animate_delay',
                            'label' => esc_html__('Animate Delay', 'cetara' ),
                            'type' => 'text',
                            'default' => '0',
                            'description' => 'Enter number. Default 0ms',
                        ),
                    ),
                ),
                array(
                    'name' => 'sub_title_section',
                    'label' => esc_html__('Sub Title', 'cetara' ),
                    'tab' => 'content',
                    'controls' => array(
                        array(
                            'name' => 'selected_icon',
                            'label' => esc_html__('Icon', 'cetara' ),
                            'type' => 'icons',
                            'fa4compatibility' => 'icon',
                        ),
                        array(
                            'name' => 'sub_title',
                            'label' => esc_html__('Sub Title', 'cetara' ),
                            'type' => 'textarea',
                            'label_block' => true,
                        ),
                        array(
                            'name' => 'sub_title_color',
                            'label' => esc_html__('Sub Title Color', 'cetara' ),
                            'type' => 'color',
                            'selectors' => [
                                '{{WRAPPER}} .kng-heading-wrap .item--sub-title' => 'color: {{VALUE}} !important;',
                            ],
                        ),
                        array(
                            'name' => 'sub_title_typography',
                            'label' => esc_html__('Sub Title Typography', 'cetara' ),
                            'type' => \Elementor\Group_Control_Typography::get_type(),
                            'control_type' => 'group',
                            'selector' => '{{WRAPPER}} .kng-heading-wrap .item--sub-title',
                        ),
                        array(
                            'name' => 'sub_title_space_bottom',
                            'label' => esc_html__('Bottom Spacer', 'cetara' ),
                            'type' => 'slider',
                            'control_type' => 'responsive',
                            'size_units' => [ 'px' ],
                            'range' => [
                                'px' => [
                                    'min' => 0,
                                    'max' => 300,
                                ],
                            ],
                            'selectors' => [
                                '{{WRAPPER}} .kng-heading-wrap .item--sub-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                            ],
                        ),
                        array(
                            'name'         => 'sub_title_ontop',
                            'label'        => esc_html__( 'On top', 'cetara' ),
                            'type'         => 'switcher',
                            'default'      => '',
                            'label_on'     => 'Hide',
                            'label_off'    => 'Show',
                        ),
                        array(
                            'name' => 'sub_title_style',
                            'label' => esc_html__('Style', 'cetara' ),
                            'type' => 'select',
                            'options' => [
                                'style-default' => 'Default',
                            ],
                            'default' => 'style-default',
                        ),
                    ),
                ),
            ),
        ),
    ),
    get_template_directory() . '/elements/classes/'
);