<?php
if ( ! class_exists( 'Redux_Instances' ) ) {
	return;
}

class CSS_Generator {
	/**
     * scssc class instance
     *
     * @access protected
     * @var scssc
     */
    protected $scssc = null;

    /**
     * ReduxFramework class instance
     *
     * @access protected
     * @var ReduxFramework
     */
    protected $redux = null;

    /**
     * Debug mode is turn on or not
     *
     * @access protected
     * @var boolean
     */
    protected $dev_mode = true;

    /**
     * opt_name of ReduxFramework
     *
     * @access protected
     * @var string
     */
    protected $opt_name = '';

	/**
	 * Constructor
	 */
	function __construct() {
		$this->opt_name = cetara_get_theme_opt_name();

		if ( empty( $this->opt_name ) ) {
			return;
		}
		$this->dev_mode = cetara_get_theme_opt( 'dev_mode', '0' ) === '1' ? true : false;
		add_filter( 'kng_scssc_on', '__return_true' );
		add_action( 'init', array( $this, 'init' ) );
	}

	/**
	 * init hook - 10
	 */
	function init() {
		if ( ! class_exists( 'scssc' ) ) {
            return;
        }

		$this->redux = Redux_Instances::get_instance( $this->opt_name );

		if ( empty( $this->redux ) || ! $this->redux instanceof ReduxFramework ) {
			return;
		}
		add_action( 'wp', array( $this, 'generate_with_dev_mode' ) );
		add_action( "redux/options/{$this->opt_name}/saved", function () {
			$this->generate_file();
		} );
	}

	function generate_with_dev_mode() {
		if ( $this->dev_mode === true ) {
			$this->generate_file(); 
		}
	}

	/**
	 * Generate options and css files
	 */
	function generate_file() {
		 
		$scss_dir = get_template_directory() . '/assets/scss/';
		$css_dir  = get_template_directory() . '/assets/css/';

		$this->scssc = new scssc();
        $this->scssc->setImportPaths( $scss_dir );

        $_options = $scss_dir . '_options.scss';

        $this->redux->filesystem->execute( 'put_contents', $_options, array(
            'content' => preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->options_output() )
        ) );
        $css_file = $css_dir . 'theme.css';
 
        $this->scssc->setFormatter( 'scss_formatter' );
        $this->redux->filesystem->execute( 'put_contents', $css_file, array(
            'content' => preg_replace( "/(?<=[^\r]|^)\n/", "\r\n", $this->scssc->compile( '@import "theme.scss"' ) )
        ) );
	}

    protected function print_scss_opt_colors($variable,$param){
        if(is_array($variable)){
            $k = [];
            $v = [];
            foreach ($variable as $key => $value) {
                $k[] = str_replace('-', '_', $key);
                $v[] = 'var(--'.str_replace(['#',' '], [''],$key).'-color)';
            }
            if($param === 'key'){
                return implode(',', $k);
            }else{
                return implode(',', $v);
            }
            
        } else {
            return $variable;
        }
    }
    protected function options_output() {
        $theme_colors              = wp_parse_args( cetara_configs('theme_colors'), cetara_custom_colors() );
        $links                     = cetara_configs('link');
        $body                      = cetara_configs('body');
        $header                    = cetara_configs('header');
        $heading                   = cetara_configs('heading');
        $menu                      = cetara_configs('menu');
        $dropdown                  = cetara_configs('dropdown');
        $mobile_menu               = cetara_configs('mobile_menu');
        $mobile_submenu            = cetara_configs('mobile_submenu');
        $ptitle                    = cetara_configs('ptitle');  
        $ptitle_overlay            = cetara_configs('ptitle_overlay'); 
        $ptitle_breadcrumb         = cetara_configs('ptitle_breadcrumb'); 
        $shop_ptitle               = cetara_configs('shop_ptitle');  
        $shop_ptitle_overlay       = cetara_configs('shop_ptitle_overlay'); 
        $shop_ptitle_breadcrumb    = cetara_configs('shop_ptitle_breadcrumb'); 
        $product_ptitle            = cetara_configs('product_ptitle');  
        $product_ptitle_overlay    = cetara_configs('product_ptitle_overlay'); 
        $product_ptitle_breadcrumb = cetara_configs('product_ptitle_breadcrumb'); 
        $button                    = cetara_configs('button');
        $meta                      = cetara_configs('meta');
        $border                    = cetara_configs('border');
        $comment                   = cetara_configs('comment');
        //$header                  = cetara_configs('header');
        $logo                      = cetara_configs('logo');
        unset($logo['default']);
        unset($logo['mobile']);

        ob_start();
 
            printf('$kng_theme_colors_key:(%s);',$this->print_scss_opt_colors($theme_colors,'key'));
            printf('$kng_theme_colors_val:(%s);',$this->print_scss_opt_colors($theme_colors,'val'));
            // color rgb only
            foreach ($theme_colors as $key => $value) {
                printf('$%1$s_color_hex: %2$s;', str_replace('-', '_', $key), $value['value']); 
            }
            // color
            foreach ($theme_colors as $key => $value) {
                printf('$%1$s_color: %2$s;', str_replace('-', '_', $key), 'var(--'.str_replace(['#',' '], [''],$key).'-color)' );
            }
             
            // link color
            foreach ($links as $key => $value) {
                printf('$link_%1$s: %2$s;', str_replace('-', '_', $key), 'var(--link-'.$key.')');
            }
            foreach ($body as $key => $value) {
                printf('$body_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($header as $key => $value) {
                printf('$header_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($heading as $key => $value) {
                printf('$heading_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($menu as $key => $value) {
                printf('$menu_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($dropdown as $key => $value) {
                printf('$dropdown_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($mobile_menu as $key => $value) {
                printf('$mobile_menu_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($mobile_submenu as $key => $value) {
                printf('$mobile_submenu_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($ptitle as $key => $value) {
                if($key === 'background-image') $value = 'url('.$value.')';
                if(!is_array($value))
                    printf('$ptitle_%1$s: var(--ptitle-%2$s);', str_replace('-', '_', $key), $key);       
            }
            foreach ($ptitle_overlay as $key => $value) {
                printf('$ptitle_overlay_%1$s: var(--ptitle-overlay-%2$s);', str_replace('-', '_', $key), $key);  
            }
            foreach ($ptitle_breadcrumb as $key => $value) {
                printf('$ptitle_breadcrumb_%1$s: var(--ptitle-breadcrumb-%2$s);', str_replace('-', '_', $key), $key);  
            }
            foreach ($shop_ptitle as $key => $value) {
                if($key === 'product-background-image') $value = 'url('.$value.')';
                if(!is_array($value))
                    printf('$shop_ptitle_%1$s: var(--shop-ptitle-%2$s);', str_replace('-', '_', $key), $key);       
            }
            foreach ($shop_ptitle_overlay as $key => $value) {
                printf('$shop_ptitle_overlay_%1$s: var(--shop-ptitle-overlay-%2$s);', str_replace('-', '_', $key), $key);  
            }
            foreach ($shop_ptitle_breadcrumb as $key => $value) {
                printf('$shop_ptitle_breadcrumb_%1$s: var(--shop-ptitle-breadcrumb-%2$s);', str_replace('-', '_', $key), $key);  
            }
            foreach ($product_ptitle as $key => $value) {
                if($key === 'product-background-image') $value = 'url('.$value.')';
                if(!is_array($value))
                    printf('$product_ptitle_%1$s: var(--product-ptitle-%2$s);', str_replace('-', '_', $key), $key);       
            }
            foreach ($product_ptitle_overlay as $key => $value) {
                printf('$product_ptitle_overlay_%1$s: var(--product-ptitle-overlay-%2$s);', str_replace('-', '_', $key), $key);  
            }
            foreach ($product_ptitle_breadcrumb as $key => $value) {
                printf('$product_ptitle_breadcrumb_%1$s: var(--product-ptitle-breadcrumb-%2$s);', str_replace('-', '_', $key), $key);  
            }
            foreach ($button as $key => $value) {
                printf('$button_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($meta as $key => $value) {
                printf('$meta_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            foreach ($border as $key => $value) {
                printf('$border_%1$s: %2$s;', str_replace('-', '_', $key), $value);
                if($key === 'color'){
                    printf('$border_%1$s_rgb: %2$s;', str_replace('-', '_', $key), $value);
                }
            }
            foreach ($comment as $key => $value) {
                printf('$comment_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }
            
            foreach ($logo as $key => $value) {
                printf('$logo_%1$s: %2$s;', str_replace('-', '_', $key), $value);
            }   
        return ob_get_clean();
 
    }
	 
}

new CSS_Generator();