<?php
/**
 * Ajax paginate links
*/
if(!function_exists('cetara_ajax_paginate_links')){
    function cetara_ajax_paginate_links($link){
        $parts = parse_url($link);
        parse_str($parts['query'], $query);
        if(isset($query['page']) && !empty($query['page'])){
            return '#' . $query['page'];
        }
        else{
            return '#1';
        }
    }
}

/**
 * AJAX HTML for pagination
*/
if(!function_exists('cetara_get_pagination_html')){
    add_action( 'wp_ajax_cetara_get_pagination_html', 'cetara_get_pagination_html' );
    add_action( 'wp_ajax_nopriv_cetara_get_pagination_html', 'cetara_get_pagination_html' );
    function cetara_get_pagination_html(){
        try{
            if(!isset($_POST['query_vars'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'cetara'));
            }
            $query = new WP_Query(sanitize_text_field($_POST['query_vars']));
            $cls = isset($_POST['cls']) ? sanitize_text_field($_POST['cls']) : '';
            ob_start();
           		cetara_posts_pagination( $query,  true, ['class' => $cls] );
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status'  => true,
                    'message' => esc_html__('Load Pagination Successfully!', 'cetara'),
                    'data'    => array(
                        'html'       => $html,
                        'query_vars' => sanitize_text_field($_POST['query_vars']),
                        'post'       => $query->have_posts()
                    ),
                )
            );
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
// Post Layout 
if(!function_exists('cetara_get_post_grid')){
    function cetara_get_post_grid($posts = [], $settings = [], $args = []){
        
        if(empty($posts) || !is_array($posts) || empty($settings) || !is_array($settings)){
            return false;
        }
        extract($settings);
        if($thumbnail_size != 'custom'){
            $img_size = $thumbnail_size;
        }
        elseif(!empty($thumbnail_custom_dimension['width']) && !empty($thumbnail_custom_dimension['height'])){
            $img_size = $thumbnail_custom_dimension['width'] . 'x' . $thumbnail_custom_dimension['height'];
        }
        else{
            $img_size = 'full';
        }
        $col_xxl = isset($settings['col_xxl']) ? 'col-xxl-'.str_replace('.', '',12 / intval($settings['col_xxl'])) : '';
        $col_xl = isset($settings['col_xl']) ? 'col-xl-'.str_replace('.', '',12 / intval( $settings['col_xl'])) : '';
        $col_lg = isset($settings['col_lg']) ? 'col-lg-'.str_replace('.', '',12 / intval( $settings['col_lg'])) : '';
        $col_md = isset($settings['col_md']) ? 'col-md-'.str_replace('.', '',12 / intval( $settings['col_md'])) : '';
        $col_sm = isset($settings['col_sm']) ? 'col-sm-'.str_replace('.', '',12 / intval( $settings['col_sm'])) : ''; 
        $col_xs = isset($settings['col_xs']) ? 'col-xs-'.str_replace('.', '',12 / intval( $settings['col_xs'])) : ''; 

        $args = wp_parse_args($args, [
            'item_class' => trim(implode(' ', ['kng-grid-item', $col_xxl, $col_xl, $col_lg, $col_md, $col_sm]))
        ]);

        

        $item_class = $args['item_class'];
        $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
        //style
        $style = 'style="';

        if(isset($settings['masonry_mode']) && $settings['gap'] !== 0){
            $style .= 'padding:'.($settings['gap']/2).'px;';
        }
        if($settings['gap_extra']!== '0'){
            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
        }
        $style .= '"';   
 
        $meta_args['separator']   =  str_replace('\"', '"', $meta_args['separator']) ;
         
        // Start build post item 
         
        foreach ($posts as $post):   
            $filter_class = kng_get_term_of_post_to_class($post->ID, array_unique($tax));
            $meta_args['post_id'] = $post->ID;
            
            //$my_post = get_post( $post->ID );
            $user_id = $post->post_author;
            $author_url = get_author_posts_url($user_id);
            ?>
            <div class="<?php echo trim(implode(' ', [$item_class, $filter_class])); ?>" <?php kng_print_html($style); ?>>
                <?php switch ($settings['layout']) {
                    case '3':
                    ?>
                    <div class="kng-item-content kng-transition clearfix">
                        <?php 
                            cetara_post_media([
                            'post_id'         => $post->ID, 
                            'size'       => $img_size,
                            'wrap_class' => '',
                            'img_class'  => 'w-100',
                        ]);  
                        ?>
                        <div class="kng-item-content-inner">
                            <h4 class="item-title">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </h4>
                            <div class="item-meta d-flex kng-meta-bottom gutters-5">
                                <div class="m-item">
                                    <div class="d-flex">
                                        <?php cetara_get_svg('calendar') ?>
                                        <span><?php echo get_the_date( 'F j, Y,', $post->ID) ?></span>
                                    </div>
                                </div>
                                <div class="m-item">
                                    <div class="d-flex">
                                        <span class="lbl"><?php echo esc_html__( 'by', 'cetara' ) ?></span>
                                        <a href="<?php echo esc_url($author_url); ?>" title="<?php the_author_meta('display_name', $user_id); ?>"><?php the_author_meta('display_name', $user_id); ?></a>
                                    </div>
                                </div>
                            </div>
                             
                            <?php if((int)$settings['excerpt_lenght'] > 0): ?>
                                <div class="kng-item-content-excerpt">
                                    <?php
                                        if(!empty($post->post_excerpt)){
                                            echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                        } else{
                                            $content = strip_shortcodes( $post->post_content );
                                            $content = apply_filters( 'the_content', $content );
                                            $content = str_replace(']]>', ']]&gt;', $content);
                                            echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                        }
                                    ?> 
                                </div>
                            <?php endif; ?>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="kng-btn-wraps kng-post-item-readmore kng-transition">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="kng-readmore kng-blog-readmore d-inline-block">
                                        <span class="kng-btn-content">
                                            <span class="kng-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                            <span class="kng-btn-icon fal fa-angle-right"></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                    <?php 
                    break;
                    default:
                ?>
                    <div class="kng-item-content kng-transition clearfix"><?php 
                        cetara_post_media([
                            'post_id'         => $post->ID, 
                            'size'       => $img_size,
                            'wrap_class' => '',
                            'img_class'  => 'w-100',
                        ]); ?>
                        <div class="kng-item-content-inner">
                              
                            <?php cetara_post_meta($meta_args);?>
                              
                            <div class="kng-item-content-title kng-heading">
                                <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>"><?php echo get_the_title($post->ID); ?></a>
                            </div>

                            <?php 
                            if($post->post_type === 'authors' && $layout == '1-author' ): 
                                $author_role       = get_post_meta($post->ID,'author_role', true );
                                $author_extra_text = get_post_meta($post->ID,'author_extra_text', true );
                                $author_socials    = get_post_meta($post->ID,'author_socials', true );
                                ?>
                                <?php if(!empty($author_role) || !empty($author_extra_text)): ?> 
                                    <div class="rol-extra row gutters-10 align-items-center">
                                        <span class="text-primary col-auto"><?php echo esc_html($author_role) ?></span>
                                        <span class="col-auto"><span class="kng-meta-separator"></span></span>
                                        <span class="text-gray col-auto"><?php echo esc_html($author_extra_text) ?></span>
                                    </div>
                                <?php endif; ?>
                            <?php endif; ?>
                              
                            <?php if((int)$settings['excerpt_lenght'] > 0): ?>
                                <div class="kng-item-content-excerpt">
                                    <?php
                                        if(!empty($post->post_excerpt)){
                                            echo wp_trim_words( $post->post_excerpt, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                        } else{
                                            $content = strip_shortcodes( $post->post_content );
                                            $content = apply_filters( 'the_content', $content );
                                            $content = str_replace(']]>', ']]&gt;', $content);
                                            echo wp_trim_words( $content, $settings['excerpt_lenght'], $settings['excerpt_more_text'] );
                                        }
                                    ?> 
                                </div>
                            <?php endif; ?>
                            <?php 
                            if($post->post_type === 'authors' && $layout == '1-author' ){
                                $author_socials    = get_post_meta($post->ID,'author_socials', true );
                                if(!empty($author_socials)){
                                    echo '<div class="event-meta-social event-meta-item d-flex gutters-18">';
                                    foreach ($author_socials as $value) {
                                        $social_item_arr = explode('||', $value);
                                        echo '<a href="'.$social_item_arr[1].'"><i class="'.$social_item_arr[0].'"></i></a>';
                                    }
                                    echo '</div>';
                                }
                            }
                            ?>
                            <?php 
                            if($post->post_type === 'events' && $layout == '1-events'): 
                                $price = get_post_meta( $post->ID, 'price', true );
                                $location = get_post_meta( $post->ID, 'location', true );
                                $start_date = get_post_meta( $post->ID, 'start_date', true );
                                $start_time = get_post_meta( $post->ID, 'start_time', true );
                                $date_time_start = $start_time .' - '. date( 'j F, Y', strtotime($start_date));
                                ?>
                                <div class="kng-event-post-meta">
                                    <?php if(!empty($price)): ?>
                                        <div class="event-meta-item">
                                            <div class="event-meta-item-title"><i class="far fa-money"></i> <?php kng_print_html($price) ?></div>
                                        </div>
                                    <?php endif; ?>
                                    <?php if(!empty($date_time_start)): ?>
                                        <div class="event-meta-item">
                                            <div class="event-meta-item-title"><i class="far fa-calendar-alt"></i> <?php kng_print_html($date_time_start) ?></div>
                                        </div>
                                    <?php endif; ?>
                                    <?php if(!empty($location)): ?>
                                        <div class="event-meta-item">
                                            <div class="event-meta-item-title"><i class="far fa-map-marker-alt"></i> <?php kng_print_html($location) ?></div>
                                        </div>
                                    <?php endif; ?>
                                </div>
                            <?php endif; ?>
                            <?php 
                            if(!empty($settings['readmore_text'])){ ?>
                                <div class="kng-btn-wraps kng-post-item-readmore kng-transition">
                                    <a href="<?php echo esc_url(get_permalink( $post->ID )); ?>" class="kng-readmore kng-blog-readmore d-inline-block">
                                        <span class="kng-btn-content">
                                            <span class="kng-btn-text"><?php echo esc_html($settings['readmore_text']); ?></span>
                                            <span class="kng-btn-icon fal fa-angle-right"></span>
                                        </span>
                                    </a>
                                </div>
                            <?php } ?>
                        </div>
                    </div>
                <?php break; 
                    } ?>
            </div>
        <?php
        endforeach;
    }
}
// Load More Post
if(!function_exists('cetara_load_more_post_grid')){
    add_action( 'wp_ajax_cetara_load_more_post_grid', 'cetara_load_more_post_grid' );
    add_action( 'wp_ajax_nopriv_cetara_load_more_post_grid', 'cetara_load_more_post_grid' );
    function cetara_load_more_post_grid(){
        try{
            if(!isset($_POST['settings'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'cetara'));
            }
            $settings = $_POST['settings'];
            
            set_query_var('paged', $settings['paged']);
            extract(kng_get_posts_of_grid($settings['post_type'], [
                'source'   => isset($settings['source'])?$settings['source']:'',
                'orderby'  => isset($settings['orderby'])?$settings['orderby']:'date',
                'order'    => isset($settings['order'])?$settings['order']:'desc',
                'limit'    => isset($settings['limit'])?$settings['limit']:'6',
                'post_ids' => '',
            ]));
            ob_start();
                cetara_get_post_grid($posts, $settings);
            $html = ob_get_clean();
            wp_send_json(
                array(
                    'status' => true,
                    'message' => esc_html__('Load Post Grid Successfully!', 'cetara'),
                    'data' => array(
                        'html'  => $html,
                        'paged' => $settings['paged'],
                        'posts' => $posts,
                    ),
                )
            );
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
// Load More Product
if(!function_exists('cetara_load_more_product_grid')){
    add_action( 'wp_ajax_cetara_load_more_product_grid', 'cetara_load_more_product_grid' );
    add_action( 'wp_ajax_nopriv_cetara_load_more_product_grid', 'cetara_load_more_product_grid' );
    function cetara_load_more_product_grid(){
        try{
            if(!isset($_POST['settings'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'cetara'));
            }
            $settings = $_POST['settings'];
            
            set_query_var('paged', $settings['paged']);
            
            $query_type         = $settings['query_type'] ? $settings['query_type'] : 'recent_product';
            $post_per_page      = $settings['limit'] ? $settings['limit'] : 10;
            $product_ids        = $settings['product_ids'] ? $settings['product_ids'] : '';
            $categories         = $settings['categories'] ? $settings['categories'] : '';
            $categories_exclude = $settings['categories_exclude'] ? $settings['categories_exclude'] : '';
            $param_args         = $settings['param_args'] ? $settings['param_args'] : [];

            $col_xxl = isset($settings['col_xxl']) ? 'col-xxl-'.str_replace('.', '',12 / intval($settings['col_xxl'])) : '';
            $col_xl = isset($settings['col_xl']) ? 'col-xl-'.str_replace('.', '',12 / intval( $settings['col_xl'])) : '';
            $col_lg = isset($settings['col_lg']) ? 'col-lg-'.str_replace('.', '',12 / intval( $settings['col_lg'])) : '';
            $col_md = isset($settings['col_md']) ? 'col-md-'.str_replace('.', '',12 / intval( $settings['col_md'])) : '';
            $col_sm = isset($settings['col_sm']) ? 'col-sm-'.str_replace('.', '',12 / intval( $settings['col_sm'])) : ''; 
            $col_xs = isset($settings['col_xs']) ? 'col-xs-'.str_replace('.', '',12 / intval( $settings['col_xs'])) : ''; 

            $item_class = trim(implode(' ', ['kng-grid-item product wow fadeInUp', $col_xxl, $col_xl, $col_lg, $col_md, $col_sm, $col_xs])); 

            $loop = cetara_woocommerce_query($query_type,$post_per_page,$product_ids,$categories,$categories_exclude,$param_args);
            extract($loop);

            $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
              
            if($posts->have_posts()){
                ob_start();
                    while ($posts->have_posts()) {
                        $posts->the_post();
                        global $product;
                        $term_list = array();
                        $term_of_post = wp_get_post_terms($product->get_ID(), 'product_cat');
                        foreach ($term_of_post as $term) {
                            $term_list[] = $term->slug;
                        }
                        $filter_class = implode(' ', $term_list);
                        
                        $style = 'style="';
                        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
                            $style .= 'padding:'.($settings['gap']/2).'px;';
                        }
                        if($settings['gap_extra']!== '0'){
                            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
                        }
                        $style .= 'animation-delay:'.($d * 50).'ms;';
                        $style .= '"'; 
                        
                        ?>
                        <div class="<?php echo trim(implode(' ', [$item_class, $filter_class])); ?>" <?php kng_print_html($style); ?>>
                            <?php
                                do_action( 'woocommerce_before_shop_loop_item' );
                                do_action( 'woocommerce_before_shop_loop_item_title' );
                                do_action( 'woocommerce_shop_loop_item_title' );
                                do_action( 'woocommerce_after_shop_loop_item_title' );
                                do_action( 'woocommerce_after_shop_loop_item' );
                            ?>
                             
                        </div>
                    <?php 
                    }  
                    ?>
                    <div class="kng-grid-overlay"></div>
                <?php
                $html = ob_get_clean();
                wp_send_json(
                    array(
                        'status' => true,
                        'message' => esc_html__('Load Post Grid Successfully!', 'cetara'),
                        'data' => array(
                            'html'  => $html,
                            'paged' => $settings['paged'],
                            'posts' => $posts,
                        ),
                    )
                );
            }else{
                wp_send_json(
                    array(
                        'status' => false,
                        'message' => esc_html__('Load Post Grid No More!', 'cetara')
                    )
                );
            }
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}

// Load Product Filter
if(!function_exists('cetara_load_product_grid_filter')){
    add_action( 'wp_ajax_cetara_load_product_grid_filter', 'cetara_load_product_grid_filter' );
    add_action( 'wp_ajax_nopriv_cetara_load_product_grid_filter', 'cetara_load_product_grid_filter' );
    function cetara_load_product_grid_filter(){
        try{
            if(!isset($_POST['settings'])){
                throw new Exception(__('Something went wrong while requesting. Please try again!', 'cetara'));
            }
            $settings = $_POST['settings'];
              
            $query_type         = $settings['query_type'] ? $settings['query_type'] : 'best_selling';
            $post_per_page      = $settings['limit'] ? $settings['limit'] : 10;
            $product_ids        = $settings['product_ids'] ? $settings['product_ids'] : '';
            $categories         = $settings['categories'] ? $settings['categories'] : '';
            $categories_exclude = $settings['categories_exclude'] ? $settings['categories_exclude'] : '';
            $param_args         = $settings['param_args'] ? $settings['param_args'] : [];

            $col_xxl = isset($settings['col_xxl']) ? 'col-xxl-'.str_replace('.', '',12 / intval($settings['col_xxl'])) : '';
            $col_xl = isset($settings['col_xl']) ? 'col-xl-'.str_replace('.', '',12 / intval( $settings['col_xl'])) : '';
            $col_lg = isset($settings['col_lg']) ? 'col-lg-'.str_replace('.', '',12 / intval( $settings['col_lg'])) : '';
            $col_md = isset($settings['col_md']) ? 'col-md-'.str_replace('.', '',12 / intval( $settings['col_md'])) : '';
            $col_sm = isset($settings['col_sm']) ? 'col-sm-'.str_replace('.', '',12 / intval( $settings['col_sm'])) : ''; 
            $col_xs = isset($settings['col_xs']) ? 'col-xs-'.str_replace('.', '',12 / intval( $settings['col_xs'])) : ''; 

            $item_class = trim(implode(' ', ['kng-grid-item product wow fadeInUp', $col_xxl, $col_xl, $col_lg, $col_md, $col_sm, $col_xs])); 

            $loop = cetara_woocommerce_query($query_type,$post_per_page,$product_ids,$categories,$categories_exclude,$param_args);
            extract($loop);

            $settings['gap_extra'] = empty($settings['gap_extra']) ? '0' : $settings['gap_extra'];
             
            if($posts->have_posts()){
                ob_start();
                    $d = 0;
                    while ($posts->have_posts()) {
                        $posts->the_post();
                        global $product;
                        $d++;
                        $term_list = array();
                        $term_of_post = wp_get_post_terms($product->get_ID(), 'product_cat');
                        foreach ($term_of_post as $term) {
                            $term_list[] = $term->slug;
                        }
                        $filter_class = implode(' ', $term_list);
                        
                        $style = 'style="';
                        if(isset($settings['masonry_mode']) && !empty($settings['gap'])){
                            $style .= 'padding:'.($settings['gap']/2).'px;';
                        }
                        if($settings['gap_extra']!== '0'){
                            $style .= 'margin-bottom:'.$settings['gap_extra'].'px;';
                        }
                        $style .= 'animation-delay:'.($d * 50).'ms;';
                        $style .= '"'; 

                        ?>
                        <div class="<?php echo trim(implode(' ', [$item_class, $filter_class])); ?>" <?php kng_print_html($style); ?>>
                            <?php
                                do_action( 'woocommerce_before_shop_loop_item' );
                                do_action( 'woocommerce_before_shop_loop_item_title' );
                                do_action( 'woocommerce_shop_loop_item_title' );
                                do_action( 'woocommerce_after_shop_loop_item_title' );
                                do_action( 'woocommerce_after_shop_loop_item' );
                            ?>
                             
                        </div>
                    <?php 
                    }  ?>
                    <div class="kng-grid-overlay"></div>
                <?php $html = ob_get_clean();
                wp_send_json(
                    array(
                        'status' => true,
                        'message' => esc_html__('Load Post Grid Successfully!', 'cetara'),
                        'data' => array(
                            'html'  => $html,
                            'posts' => $posts,
                        ),
                    )
                );
            }else{
                wp_send_json(
                    array(
                        'status' => false,
                        'message' => esc_html__('Load Post Grid No More!', 'cetara')
                    )
                );
            }
        }
        catch (Exception $e){
            wp_send_json(array('status' => false, 'message' => $e->getMessage()));
        }
        die;
    }
}
 