<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  KNG_Post_Metabox $metabox
 */


add_action( 'kng_post_metabox_register', 'cetara_page_options_register' );
function cetara_page_options_register( $metabox ) {
	if ( ! $metabox->isset_args( 'page' ) ) {
		$metabox->set_args( 'page', array(
			'opt_name'            => cetara_get_page_opt_name(),
			'display_name'        => esc_html__( 'Page Settings', 'cetara' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	$menus = ['-1' => esc_html__('Theme Options','cetara')] + cetara_get_nav_menu();

	/**
	 * Config page meta options
	 *
	 */
 
	// Main Header
	$metabox->add_section( 
		'page',  
		array(
		    'title'  => esc_html__('Header', 'cetara'),
		    'icon'   => 'el-icon-website',
		    'fields' => array_merge(
		        cetara_header_opts([
					'default'         => true,
					'default_value'   => '-1',
					'container_width' => '-1'
				])
		    )
		)
	);
	$metabox->add_section( 
		'page',  
		array(
		    'title'  => esc_html__('Header Mobile', 'cetara'),
	        'icon'       => 'el-icon-website',
		    'fields' => array_merge(
		        cetara_header_mobile_opts([
					'default'         => true,
					'default_value'   => '-1'
				]),
				array(
					array(
						'title'  => esc_html__('Menu mobile panel', 'cetara'),
						'type'   => 'section',
						'id'     => 'mobile_menu_panel',
						'indent' => true
			        ),
					array(
						'title'       => esc_html__('Choose Menu', 'cetara'),
						'subtitle'    => esc_html__('Choose your menu', 'cetara'),
						'placeholder' => esc_html__('Choose your menu', 'cetara'),
						'id'          => 'mobile_panel_menu',
						'type'        => 'select',
						'options'     => $menus,
						'default'     => '-1',
			        )
				)
		    )
		)
	);
	 
  
	// Page title
	$metabox->add_section( 'page', cetara_page_title_opts(['default' => true, 'default_value' => '-1']));
	// Sidebar
	$metabox->add_section('page', cetara_page_layout_opts(['default' => true, 'subsection' => false]));
	// Footer 
	$metabox->add_section('page', cetara_footer_opts(['default' => true, 'default_value'=>'-1', 'subsection' => false]));
}

function cetara_get_option_of_theme_options( $key, $default = '' ) {
	if ( empty( $key ) ) {
		return '';
	}
	$options = get_option( cetara_get_opt_name(), array() );
	$value   = isset( $options[ $key ] ) ? $options[ $key ] : $default;

	return $value;
}