<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  KNG_Post_Metabox $metabox
 */

add_action( 'kng_post_metabox_register', 'cetara_post_options_register' );
function cetara_post_options_register( $metabox ) {
	if ( ! $metabox->isset_args( 'post' ) ) {
		$metabox->set_args( 'post', array(
			'opt_name'            => 'post_option',
			'display_name'        => esc_html__( 'Post Settings', 'cetara' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	if ( ! $metabox->isset_args( 'kng_pf_audio' ) ) {
		$metabox->set_args( 'kng_pf_audio', array(
			'opt_name'     => 'post_format_audio',
			'display_name' => esc_html__( 'Audio', 'cetara' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	if ( ! $metabox->isset_args( 'kng_pf_link' ) ) {
		$metabox->set_args( 'kng_pf_link', array(
			'opt_name'     => 'post_format_link',
			'display_name' => esc_html__( 'Link', 'cetara' )
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	if ( ! $metabox->isset_args( 'kng_pf_quote' ) ) {
		$metabox->set_args( 'kng_pf_quote', array(
			'opt_name'     => 'post_format_quote',
			'display_name' => esc_html__( 'Quote', 'cetara' )
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	if ( ! $metabox->isset_args( 'kng_pf_video' ) ) {
		$metabox->set_args( 'kng_pf_video', array(
			'opt_name'     => 'post_format_video',
			'display_name' => esc_html__( 'Video', 'cetara' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	if ( ! $metabox->isset_args( 'kng_pf_gallery' ) ) {
		$metabox->set_args( 'kng_pf_gallery', array(
			'opt_name'     => 'post_format_gallery',
			'display_name' => esc_html__( 'Gallery', 'cetara' ),
			'class'        => 'fully-expanded',
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	  
	// Sidebar
	$metabox->add_section('post', 
		array(
		    'title'      => esc_html__('Sidebar Position', 'cetara'),
		    'icon'       => 'el-icon-list',
		    'subsection' => true,
		    'fields'     => array(
				cetara_sidebar_opts(['name' => 'single_sidebar_pos', 'default' => true, 'subsection' => true])
			)
		)
	);
	// Post title
	$metabox->add_section( 'post', cetara_page_title_opts([
		'default'        => false,
		'default_value'  => '1',
		'default_layout' => cetara_configs('single_post')['title_layout']
	]));
	/**
	 * Config post format meta options
	 *
	*/
	$metabox->add_section( 'kng_pf_video', array(
		'title'  => esc_html__( 'Video', 'cetara' ),
		'fields' => array(
			array(
				'id'    => 'post-video-url',
				'type'  => 'text',
				'title' => esc_html__( 'Video URL', 'cetara' ),
				'desc'  => esc_html__( 'YouTube or Vimeo video URL', 'cetara' )
			),

			array(
				'id'             => 'post-video-file',
				'type'           => 'media',
				'title'          => esc_html__( 'Video Upload', 'cetara' ),
				'desc'           => esc_html__( 'Upload video file', 'cetara' ),
				'library_filter' => array('mp4', 'mov', 'mp3'),
				'mode'           => false,
			),

			array(
				'id'    => 'post-video-html',
				'type'  => 'textarea',
				'title' => esc_html__( 'Embadded video', 'cetara' ),
				'desc'  => esc_html__( 'Use this option when the video does not come from YouTube or Vimeo', 'cetara' )
			)
		)
	) );

	$metabox->add_section( 'kng_pf_gallery', array(
		'title'  => esc_html__( 'Gallery', 'cetara' ),
		'fields' => array(
			array(
				'id'       => 'post-gallery-lightbox',
				'type'     => 'select',
				'title'    => esc_html__( 'Lightbox?', 'cetara' ),
				'subtitle' => esc_html__( 'Enable lightbox for gallery images.', 'cetara' ),
				'default'  => 'yes',
				'options' => [
					'yes' => esc_html__('Yes', 'cetara'),
					'no'  => esc_html__('No', 'cetara')
				]
			),
			array(
				'id'       => 'post-gallery-images',
				'type'     => 'gallery',
				'title'    => esc_html__( 'Gallery Images ', 'cetara' ),
				'subtitle' => esc_html__( 'Upload images or add from media library.', 'cetara' )
			)
		)
	) );

	$metabox->add_section( 'kng_pf_audio', array(
		'title'  => esc_html__( 'Audio', 'cetara' ),
		'fields' => array(
			array(
				'id'          => 'post-audio-url',
				'type'        => 'text',
				'title'       => esc_html__( 'Audio URL', 'cetara' ),
				'description' => esc_html__( 'Audio file URL in format: mp3, ogg, wav.', 'cetara' ),
				'validate'    => 'url',
				'msg'         => 'Url error!'
			)
		)
	) );

	$metabox->add_section( 'kng_pf_link', array(
		'title'  => esc_html__( 'Link', 'cetara' ),
		'fields' => array(
			array(
				'id'       => 'post-link-url',
				'type'     => 'text',
				'title'    => esc_html__( 'URL', 'cetara' ),
				'validate' => 'url',
				'msg'      => 'Url error!'
			)
		)
	) );

	$metabox->add_section( 'kng_pf_quote', array(
		'title'  => esc_html__( 'Quote', 'cetara' ),
		'fields' => array(
			array(
				'id'    => 'post-quote-cite',
				'type'  => 'text',
				'title' => esc_html__( 'Cite', 'cetara' )
			)
		)
	) );
 
}