<?php
/**
 * Register metabox for posts based on Redux Framework. Supported methods:
 *     isset_args( $post_type )
 *     set_args( $post_type, $redux_args, $metabox_args )
 *     add_section( $post_type, $sections )
 * Each post type can contains only one metabox. Pease note that each field id
 * leads by an underscore sign ( _ ) in order to not show that into Custom Field
 * Metabox from WordPress core feature.
 *
 * @param  KNG_Post_Metabox $metabox
 */

add_action( 'kng_post_metabox_register', 'cetara_post_type_options_register' );
function cetara_post_type_options_register( $metabox ) {
	if ( ! $metabox->isset_args( 'kng-header' ) ) {
		$metabox->set_args( 'kng-header', array(
			'opt_name'            => 'kng_header_option',
			'display_name'        => esc_html__( 'Header Type', 'cetara' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}
	if ( ! $metabox->isset_args( 'events' ) ) {
		$metabox->set_args( 'events', array(
			'opt_name'            => 'events_option',
			'display_name'        => esc_html__( 'Event Options', 'cetara' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'authors' ) ) {
		$metabox->set_args( 'authors', array(
			'opt_name'            => 'authors_option',
			'display_name'        => esc_html__( 'Author Options', 'cetara' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	if ( ! $metabox->isset_args( 'product' ) ) {
		$metabox->set_args( 'product', array(
			'opt_name'            => 'product_option',
			'display_name'        => esc_html__( 'Product Options', 'cetara' ),
			'show_options_object' => false,
		), array(
			'context'  => 'advanced',
			'priority' => 'default'
		) );
	}

	$metabox->add_section( 'kng-header', array(
		'title'  => esc_html__( 'Header Type', 'cetara' ),
		'fields' => array(
			array(
				'id'       => 'kng_header_type',
				'type'     => 'button_set',
				'title'    => esc_html__( 'Sticky?', 'cetara' ),
				'subtitle' => esc_html__( 'Yes(sticky) / No(default).', 'cetara' ),
				'default'  => 'no',
				'options' => [
					'yes' => esc_html__('Yes', 'cetara'),
					'no'  => esc_html__('No', 'cetara')
				]
			)   
		)
	) );

	$metabox->add_section( 'events', array(
		'title'  => esc_html__( 'Location', 'cetara' ),
		'fields' => array(
			array(
                'id'            => 'location',
                'type'          => 'text',
                'title'    		=> esc_html__( 'Location', 'cetara' ),
				'subtitle' 		=> esc_html__( 'Enter the event location', 'cetara' ),
                'default'       => '',
                'placeholder'   => 'www.cetara.com',
            ),
            array(
                'id'            => 'custom_category',
                'type'          => 'text',
                'title'    		=> esc_html__( 'Custom category', 'cetara' ),
				'subtitle' 		=> esc_html__( 'Enter the event category', 'cetara' ),
				'default'       => '',
                'placeholder'   => esc_attr__('Art & Photography','cetara'),
            ),
            array(
                'id'            => 'price',
                'type'          => 'text',
                'title'    		=> esc_html__( 'Price', 'cetara' ),
				'subtitle' 		=> esc_html__( 'Enter the event price', 'cetara' ),
                'default'       => '',
                'placeholder'   => esc_attr__('From $15', 'cetara' ),
            ),
		)
	) );
	$metabox->add_section( 'events', array(
		'title'  => esc_html__( 'Time', 'cetara' ),
		'fields' => array(
			array(
				'id'       => 'start_date',
				'type'     => 'date',
				'title'    => esc_html__( 'Start Date', 'cetara' ),
				'subtitle' => esc_html__( 'Choose event date start', 'cetara' ),
				'placeholder' => esc_attr__('Click to enter a date','cetara'),
			),
			array(
                'id'          => 'start_time',
                'type'        => 'text',
                'title'       => esc_html__('Start Time', 'cetara'),
                'subtitle'    => esc_html__('Enter the event start time', 'cetara'),
                'placeholder' => esc_attr__('09:00 am', 'cetara'),
                'default'     => '',
            ), 
            array(
				'id'       => 'end_date',
				'type'     => 'date',
				'title'    => esc_html__( 'End Date', 'cetara' ),
				'subtitle' => esc_html__( 'Choose event date end', 'cetara' ),
				'placeholder' => esc_attr__('Click to enter a date','cetara'),
			),
			array(
                'id'          => 'end_time',
                'type'        => 'text',
                'title'       => esc_html__('End Time', 'cetara'),
                'subtitle'    => esc_html__('Enter the event end time ', 'cetara'),
                'placeholder' => esc_attr__('09:00 am', 'cetara'),
                'default'     => '',
            ), 
		)
	) );
	$metabox->add_section( 'events', array(
		'title'  => esc_html__( 'Additional Info', 'cetara' ),
		'fields' => array(
            array(
				'id'       => 'event_socials',
				'type'     => 'multi_text',
				'default'  => ['fa fa-facebook||https://facebook.com'],
				'title'    => esc_html__('Add more event social information', 'cetara'),
				'subtitle' => esc_html__('Split awesome icon font class and link by mark: || Ex: far fa-facebook||https://facebook.com', 'cetara'),
			),
		)
	) );
	$metabox->add_section( 'authors', array(
		'title'  => esc_html__( 'Additional Info', 'cetara' ),
		'fields' => array(
			array(
                'id'          => 'author_role',
                'type'        => 'text',
                'title'       => esc_html__('Author Role', 'cetara'),
                'subtitle'    => esc_html__('Enter the role of author', 'cetara'),
                'placeholder' => esc_attr__('Author', 'cetara'),
                'default'     => esc_html__('Author', 'cetara'),
            ), 
            array(
                'id'          => 'author_extra_text',
                'type'        => 'text',
                'title'       => esc_html__('Author Extra Text', 'cetara'),
                'placeholder' => esc_attr__('03 Published Books', 'cetara'),
                'default'     => esc_html__('03 Published Books', 'cetara'),
            ), 
            array(
				'id'       => 'author_socials',
				'type'     => 'multi_text',
				'default'  => ['fa fa-facebook||https://facebook.com'],
				'title'    => esc_html__('Add more event social information', 'cetara'),
				'subtitle' => esc_html__('Split awesome icon font class and link by mark: || Ex: far fa-facebook||https://facebook.com', 'cetara'),
			),
		)
	) );
 
	$metabox->add_section( 'product', array(
		'title'  => esc_html__( 'Extra Options', 'cetara' ),
		'fields' => array(
			array(
                'id'          => 'product_author',
                'type'        => 'select',
                'title'       => esc_html__('Select Author', 'cetara'),
                'options'     => cetara_list_post('authors',false),
                'default'     => '',
            ), 
             
		)
	) );
}