<?php
if (!class_exists('ReduxFramework')) {
    return;
}
if (class_exists('ReduxFrameworkPlugin')) {
    remove_action('admin_notices', array(ReduxFrameworkPlugin::instance(), 'admin_notices'));
}
 
$opt_name = cetara_get_theme_opt_name();
$theme = wp_get_theme();

$args = array(
    // TYPICAL -> Change these values as you need/desire
    'opt_name'             => $opt_name,
    // This is where your data is stored in the database and also becomes your global variable name.
    'display_name'         => $theme->get('Name'),
    // Name that appears at the top of your panel
    'display_version'      => $theme->get('Version'),
    // Version that appears at the top of your panel
    'menu_type'            => class_exists('Kngtheme_Core') ? 'submenu' : '',
    //Specify if the admin menu should appear or not. Options: menu or submenu (Under appearance only)
    'allow_sub_menu'       => true,
    // Show the sections below the admin menu item or not
    'menu_title'           => esc_html__('Theme Options', 'cetara'),
    'page_title'           => esc_html__('Theme Options', 'cetara'),
    // You will need to generate a Google API key to use this feature.
    // Please visit: https://developers.google.com/fonts/docs/developer_api#Auth
    'google_api_key'       => '',
    // Set it you want google fonts to update weekly. A google_api_key value is required.
    'google_update_weekly' => false,
    // Must be defined to add google fonts to the typography module
    'async_typography'     => false,
    // Use a asynchronous font on the front end or font string
    //'disable_google_fonts_link' => true,                    // Disable this in case you want to create your own google fonts loader
    'admin_bar'            => true,
    // Show the panel pages on the admin bar
    'admin_bar_icon'       => 'dashicons-admin-generic',
    // Choose an icon for the admin bar menu
    'admin_bar_priority'   => 50,
    // Choose an priority for the admin bar menu
    'global_variable'      => '',
    // Set a different name for your global variable other than the opt_name
    'dev_mode'             => true,
    // Show the time the page took to load, etc
    'update_notice'        => true,
    // If dev_mode is enabled, will notify developer of updated versions available in the GitHub Repo
    'customizer'           => true,
    // Enable basic customizer support
    //'open_expanded'     => true,                    // Allow you to start the panel in an expanded way initially.
    //'disable_save_warn' => true,                    // Disable the save warning when a user changes a field
    'show_options_object' => false,
    // OPTIONAL -> Give you extra features
    'page_priority'        => null,
    // Order where the menu appears in the admin area. If there is any conflict, something will not show. Warning.
    'page_parent'          => class_exists('Kngtheme_Core') ? $theme->get('TextDomain') : '',
    // For a full list of options, visit: //codex.wordpress.org/Function_Reference/add_submenu_page#Parameters
    'page_permissions'     => 'manage_options',
    // Permissions needed to access the options panel.
    'menu_icon'            => '',
    // Specify a custom URL to an icon
    'last_tab'             => '',
    // Force your panel to always open to a specific tab (by id)
    'page_icon'            => 'icon-themes',
    // Icon displayed in the admin panel next to your menu_title
    'page_slug'            => 'theme-options',
    // Page slug used to denote the panel, will be based off page title then menu title then opt_name if not provided
    'save_defaults'        => true,
    // On load save the defaults to DB before user clicks save or not
    'default_show'         => false,
    // If true, shows the default value next to each field that is not the default value.
    'default_mark'         => '',
    // What to print by the field's title if the value shown is default. Suggested: *
    'show_import_export'   => false,
    // Shows the Import/Export panel when not used as a field.

    // CAREFUL -> These options are for advanced use only
    'transient_time'       => 60 * MINUTE_IN_SECONDS,
    'output'               => true,
    // Global shut-off for dynamic CSS output by the framework. Will also disable google fonts output
    'output_tag'           => true,
    // Allows dynamic CSS to be generated for customizer and google fonts, but stops the dynamic CSS from going to the head
    // 'footer_credit'     => '',                   // Disable the footer credit of Redux. Please leave if you can help it.

    // FUTURE -> Not in use yet, but reserved or partially implemented. Use at your own risk.
    'database'             => '',
    // possible: options, theme_mods, theme_mods_expanded, transient. Not fully functional, warning!
    'use_cdn'              => true,
    // If you prefer not to use the CDN for Select2, Ace Editor, and others, you may download the Redux Vendor Support plugin yourself and run locally or embed it in your code.

    // HINTS
    'hints'             => array(
        'icon'          => 'el el-question-sign',
        'icon_position' => 'right',
        'icon_color'    => 'lightgray',
        'icon_size'     => 'normal',
        'tip_style'     => array(
            'color'   => 'red',
            'shadow'  => true,
            'rounded' => false,
            'style'   => '',
        ),
        'tip_position'  => array(
            'my' => 'top left',
            'at' => 'bottom right',
        ),
        'tip_effect'    => array(
            'show' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'mouseover',
            ),
            'hide' => array(
                'effect'   => 'slide',
                'duration' => '500',
                'event'    => 'click mouseleave',
            ),
        ),
    )
);

Redux::SetArgs($opt_name, $args);

/*--------------------------------------------------------------
# General
--------------------------------------------------------------*/

Redux::setSection($opt_name, array(
    'title'  => esc_html__('General', 'cetara'),
    'icon'   => 'el-icon-home',
    'fields' => array()
));
/*--------------------------------------------------------------
# Colors
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Colors', 'cetara'),
    'icon'       => 'dashicons dashicons-dashboard',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'primary_color',
            'type'        => 'color',
            'title'       => esc_html__('Primary Color', 'cetara'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'second_color',
            'type'        => 'color',
            'title'       => esc_html__('Secondary Color', 'cetara'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'second_color2',
            'type'        => 'color',
            'title'       => esc_html__('Secondary Color 2', 'cetara'),
            'transparent' => false,
            'default'     => '#FFF6F0'
        ),
        array(
            'id'          => 'third_color',
            'type'        => 'color',
            'title'       => esc_html__('Third Color', 'cetara'),
            'transparent' => false,
            'default'     => ''
        ),
        array(
            'id'          => 'rating_color',
            'type'        => 'color',
            'title'       => esc_html__('Rating Color', 'cetara'),
            'transparent' => false,
            'default'     => ''
        ),
        
        array(
            'id'          => 'link_color',
            'type'        => 'link_color',
            'title'       => esc_html__('Link Color', 'cetara')
        )
    )
));

/*--------------------------------------------------------------
# Tools
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Tools', 'cetara'),
    'icon'       => 'el-icon-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'show_page_loading',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Page Loading', 'cetara'),
            'subtitle' => esc_html__('Enable page loading effect when you load site.', 'cetara'),
            'default'  => '0'
        ),
        array(
            'id'       => 'back_totop_on',
            'type'     => 'switch',
            'title'    => esc_html__('Enable Back To Top', 'cetara'),
            'default'  => '1'
        ),
        array(
            'id'       => 'dev_mode',
            'type'     => 'switch',
            'title'    => esc_html__('Dev Mode (not recommended)', 'cetara'),
            'description' => esc_html__('no minimize , generate css over time...', 'cetara'),
            'default'  => false
        )
    )
));
/*--------------------------------------------------------------
# Typography
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
    'title'  => esc_html__('Typography', 'cetara'),
    'icon'   => 'el-icon-text-width',
    'fields' => array(
        array(
            'id'       => 'body_typo',
            'type'     => 'select',
            'title'    => esc_html__('Body Typography', 'cetara'),
            'options'  => array(
                'default' => esc_html__('Default', 'cetara'),
                'custom'  => esc_html__('Custom', 'cetara'),
            ),
            'default'  => 'default',

        ),
        array(
            'id'             => 'body_font_typo',
            'type'           => 'typography',
            'title'          => esc_html__('Body Google Font', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'required'       => array( 0 => 'body_typo', 1 => 'equals', 2 => 'custom' ),
            'output'           => 'body'
        ),
        array(
            'id'       => 'heading_font_typo',
            'type'     => 'select',
            'title'    => esc_html__('Heading Typography', 'cetara'),
            'options'  => array(
                'default' => esc_html__('Default', 'cetara'),
                'custom'  => esc_html__('Google Font', 'cetara'),
            ),
            'default'  => 'default',
        ),
        array(
            'id'             => 'h1_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H1', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font for all H1 tags of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'output'      => array('h1', '.h1'),
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id'             => 'h2_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H2', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font for all H2 tags of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'output'      => array('h2', '.h2'),
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id'             => 'h3_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H3', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font for all H3 tags of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'output'      => array('h3', '.h3'),
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id'             => 'h4_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H4', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font for all H4 tags of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'output'      => array('h4', '.h4'),
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id'             => 'h5_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H5', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font for all H5 tags of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'output'      => array('h5', '.h5'),
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        ),
        array(
            'id'             => 'h6_typo',
            'type'           => 'typography',
            'title'          => esc_html__('H6', 'cetara'),
            'subtitle'       => esc_html__('This will be the default font for all H6 tags of your website.', 'cetara'),
            'letter-spacing' => true,
            'text-align'     => false,
            'units'          => 'px',
            'output'      => array('h6', '.h6'),
            'required'       => array( 0 => 'heading_font_typo', 1 => 'equals', 2 => 'custom' ),
            'force_output' => true
        )
    )
));
$custom_font_selectors_1 = Redux::get_option($opt_name, 'custom_font_selectors_1');
$custom_font_selectors_1 = !empty($custom_font_selectors_1) ? explode(',', $custom_font_selectors_1) : array();
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Custom Fonts', 'cetara'),
    'icon'       => 'el el-fontsize',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'          => 'custom_font_1',
            'type'        => 'typography',
            'title'       => esc_html__('Custom Font', 'cetara'),
            'subtitle'    => esc_html__('This will be the font that applies to the class selector.', 'cetara'),
            'text-align'  => false,
            'output'      => $custom_font_selectors_1,
            'units'       => 'px',
        ),
        array(
            'id'       => 'custom_font_selectors_1',
            'type'     => 'textarea',
            'title'    => esc_html__('CSS Selectors', 'cetara'),
            'subtitle' => esc_html__('Add class selectors to apply above font.', 'cetara'),
            'validate' => 'no_html'
        )
    )
));
  
// Header layout
Redux::setSection(
    $opt_name, 
    array(
        'title'  => esc_html__('Header', 'cetara'),
        'icon'   => 'el-icon-website',
        'fields' => array_merge(
            cetara_header_opts() 
        )
    )
);

Redux::setSection(
    $opt_name, 
    array(
        'title'  => esc_html__('Header Mobile', 'cetara'),
        'icon'       => 'el-icon-website',
        'fields' => array_merge(
            cetara_header_mobile_opts()      
        )
    )
);
Redux::setSection(
    $opt_name, 
    array(
        'title'  => esc_html__('Mobile Menu Panel', 'cetara'),
        'icon'       => 'el-icon-website',
        'fields' => cetara_mobile_menu_panel_opts()    
    )
);
 
 
/*--------------------------------------------------------------
# Page Title area
--------------------------------------------------------------*/

Redux::setSection($opt_name, cetara_page_title_opts());

/*--------------------------------------------------------------
# WordPress default content
--------------------------------------------------------------*/
Redux::setSection($opt_name, array(
        'title'  => esc_html__('Content', 'cetara'),
        'icon'   => 'el-icon-pencil',
        'fields' => array(
        array(
            'id'       => 'content_bg_color',
            'type'     => 'color_rgba',
            'title'    => esc_html__('Background Color', 'cetara'),
            'subtitle' => esc_html__('Content background color.', 'cetara'),
            'output'   => array('background-color' => '.kng-main')
        ),
        array(
            'id'             => 'content_padding',
            'type'           => 'spacing',
            'output'         => array('#kng-main'),
            'right'          => false,
            'left'           => false,
            'mode'           => 'padding',
            'units'          => array('px'),
            'units_extended' => 'false',
            'title'          => esc_html__('Content Padding', 'cetara'),
            'desc'           => esc_html__('Default: Top-90px, Bottom-90px', 'cetara'),
            'default'        => array(
                'padding-top'    => '',
                'padding-bottom' => '',
                'units'          => 'px',
            )
        ),
        array(
            'id'      => 'search_field_placeholder',
            'type'    => 'text',
            'title'   => esc_html__('Search Form - Text Placeholder', 'cetara'),
            'default' => '',
            'desc'           => esc_html__('Default: Search...', 'cetara'),
        )
    )
));
// Single Page
Redux::setSection($opt_name, cetara_page_layout_opts() );

// Archive
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Archive', 'cetara'),
    'icon'       => 'el-icon-list',
    'subsection' => true,
    'fields'     => array(
        cetara_sidebar_opts([
            'name'          => 'archive_sidebar_pos',
            'fields_only'   =>  true,
            'default_value' => cetara_configs('blog')['archive_sidebar_pos']  
        ]),
        array(
            'id'            => 'archive_content_col',
            'title'         => esc_html__('Content Columns', 'cetara'),
            'subtitle'      => esc_html__('Choose content Columns', 'cetara'),
            'type'          => 'slider',
            'default'       => cetara_configs('blog')['archive_content_col'],
            'min'           => 1,
            'step'          => 1,
            'max'           => 11,
            'display_value' => 'label',
            'required'      => [ 
                ['archive_sidebar_pos', '!=', '0'],
                ['archive_sidebar_pos', '!=', 'bottom']
            ],
        ),
        array(
            'id'       => 'archive_categories_on',
            'title'    => esc_html__('Categories', 'cetara'),
            'subtitle' => esc_html__('Show category names on each post.', 'cetara'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_author_on',
            'title'    => esc_html__('Author', 'cetara'),
            'subtitle' => esc_html__('Show author name on each post.', 'cetara'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_date_on',
            'title'    => esc_html__('Date', 'cetara'),
            'subtitle' => esc_html__('Show date posted on each post.', 'cetara'),
            'type'     => 'switch',
            'default'  => true,
        ),
        array(
            'id'       => 'archive_comments_on',
            'title'    => esc_html__('Comments', 'cetara'),
            'subtitle' => esc_html__('Show comments count on each post.', 'cetara'),
            'type'     => 'switch',
            'default'  => false,
        ),
    )
));
// Sinlge post
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Post', 'cetara'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'           => 'single_post_pagetitle',
            'type'         => 'button_set',
            'title'        => esc_html__( 'Page Title', 'cetara' ),
            'subtitle'     => esc_html__('Show/Hide page title?', 'cetara'),
            'options'      => [
                '1'  => esc_html__('Show','cetara'),
                '0'  => esc_html__('Hide','cetara'),
            ],
            'default'      => '0'
        ),
        array(
            'id'       => 'single_post_title_layout',
            'type'     => 'button_set',
            'title'    => esc_html__('Post title layout', 'cetara'),
            'options'  => array(
                '0' => esc_html__('Default', 'cetara'),
                '1' => esc_html__('For Blog Post', 'cetara'),
            ),
            'default'  => '1'
        ),
        cetara_sidebar_opts([
            'name'          => 'single_sidebar_pos',
            'fields_only'   =>  true,
            'default_value' => cetara_configs('blog')['single_sidebar_pos']  
        ]),
        array(
            'id'            => 'single_content_col',
            'title'         => esc_html__('Content Columns', 'cetara'),
            'subtitle'      => esc_html__('Choose content Columns', 'cetara'),
            'type'          => 'slider',
            'default'       => cetara_configs('blog')['single_content_col'],
            'min'           => 1,
            'step'          => 1,
            'max'           => 12,
            'display_value' => 'label',
            'required'      => [ 
                ['single_sidebar_pos', '!=', '0'],
                ['single_sidebar_pos', '!=', 'bottom']
            ],
        ),
        array(
            'id'       => 'post_categories_on',
            'title'    => esc_html__('Categories', 'cetara'),
            'subtitle' => esc_html__('Show category names on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_author_on',
            'title'    => esc_html__('Author', 'cetara'),
            'subtitle' => esc_html__('Show author name on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_author_info_on',
            'title'    => esc_html__('Author Info (Biographical Info must not empty)', 'cetara'),
            'subtitle' => esc_html__('Show author info name on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '0'
        ),
        array(
            'id'       => 'post_date_on',
            'title'    => esc_html__('Date', 'cetara'),
            'subtitle' => esc_html__('Show date on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        
        array(
            'id'       => 'post_tags_on',
            'title'    => esc_html__('Tags', 'cetara'),
            'subtitle' => esc_html__('Show tag names on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_comments_on',
            'title'    => esc_html__('Comments', 'cetara'),
            'subtitle' => esc_html__('Show comments count on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '0'
        ),
        array(
            'id'       => 'post_social_share_on',
            'title'    => esc_html__('Social Share', 'cetara'),
            'subtitle' => esc_html__('Show social share on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1',
        ),
        array(
            'id'       => 'post_social_share_icon',
            'type'     => 'button_set',
            'title'    => esc_html__('Social Share', 'cetara'),
            'subtitle' => esc_html__('Show social share on single post.', 'cetara'),
            'multi'    => true,
            'options' => array(
                'facebook'  => esc_html__('Facebook', 'cetara'),
                'instagram' => esc_html__('Instagram', 'cetara'),
                'twitter'   => esc_html__('Twitter', 'cetara'),
                'linkedin'  => esc_html__('Linkedin', 'cetara'),
                'pinterest' => esc_html__('Pinterest', 'cetara'),
                'google'    => esc_html__('Google Plus', 'cetara')
            ), 
            'default' => array('facebook', 'instagram', 'twitter', 'linkedin', 'google'),
            'required' => [
               'post_social_share_on',
               'equals',
               '1' 
            ]
        ),
        array(
            'id'       => 'post_nav_link_on',
            'title'    => esc_html__('Post Navigation', 'cetara'),
            'subtitle' => esc_html__('Show next/preview Navigation.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1',
        ),
        array(
            'id'       => 'post_nav_title_on',
            'title'    => esc_html__('Post Title Navigation ', 'cetara'),
            'subtitle' => esc_html__('Show next/preview Post Title.', 'cetara'),
            'type'     => 'switch',
            'default'  => '0',
            'required' => [
               'post_nav_link_on',
               'equals',
               '1' 
            ]
        ),
        array(
            'id'       => 'post_comments_form_on',
            'title'    => esc_html__('Comments Form', 'cetara'),
            'subtitle' => esc_html__('Show comments form on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_comments_rating_on',
            'title'    => esc_html__('Comments Rating', 'cetara'),
            'subtitle' => esc_html__('Show comments rating field on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '0',
            'required' => [
               'post_comments_form_on',
               'equals',
               '1' 
            ]
        ),
        array(
            'id'       => 'post_feature_image_on',
            'title'    => esc_html__('Feature Image', 'cetara'),
            'subtitle' => esc_html__('Show feature image on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '1'
        ),
        array(
            'id'       => 'post_feature_image_type',
            'type'     => 'button_set',
            'title'    => esc_html__('Feature Image Type', 'cetara'),
            'subtitle' => esc_html__('Feature image Type on single post.', 'cetara'),
            'options' => array(
                'cropped'  => esc_html__('Cropped Image', 'cetara'),
                'full'  => esc_html__('Full Image', 'cetara'),
                'background' => esc_html__('Background image', 'cetara')
            ), 
            'default' => 'cropped',
            'required' => [
               'post_feature_image_on',
               'equals',
               '1' 
            ]
        ),
        array(
            'id'       => 'post_related_on',
            'title'    => esc_html__('Related Post', 'cetara'),
            'subtitle' => esc_html__('Show related on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '0'
        ),
        array(
            'id'       => 'recent_post_on',
            'title'    => esc_html__('Recent Post', 'cetara'),
            'subtitle' => esc_html__('Show Recent on single post.', 'cetara'),
            'type'     => 'switch',
            'default'  => '0'
        ),
        array(
            'id'       => 'recent_post_title',
            'type'     => 'text',
            'title'    => esc_html__('Recent Post Title', 'cetara'),
            'default'  => esc_html__('From Our Blog', 'cetara'),
            'required' => [
               'recent_post_on',
               'equals',
               '1' 
            ]
        ),
        array(
            'id'       => 'recent_post_style',
            'type'     => 'button_set',
            'title'    => esc_html__('Recent Post Style', 'cetara'),
            'options' => array(
                'style-1'  => esc_html__('Style 1', 'cetara'),
                'style-2'  => esc_html__('Style 2', 'cetara'),
            ), 
            'default' => 'style-1',
            'required' => [
               'recent_post_on',
               'equals',
               '1' 
            ]
        ),
    )
));
// Sinlge post
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Events', 'cetara'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'single_events_page_title',
            'type'     => 'button_set',
            'title'    => esc_html__('Single Events Page Title', 'cetara'),
            'options'  => array(
                '1' => esc_html__('On', 'cetara'),
                '0' => esc_html__('Off', 'cetara'),
            ),
            'default'  => '0'
        ),
    )
));
// Sinlge post
Redux::setSection($opt_name, array(
    'title'      => esc_html__('Single Author', 'cetara'),
    'icon'       => 'el-icon-file-edit',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'single_author_page_title',
            'type'     => 'button_set',
            'title'    => esc_html__('Single Author Page Title', 'cetara'),
            'options'  => array(
                '1' => esc_html__('On', 'cetara'),
                '0' => esc_html__('Off', 'cetara'),
            ),
            'default'  => '0'
        ),
        array(
            'id'       => 'single_author_book',
            'type'     => 'button_set',
            'title'    => esc_html__('Single Author Book', 'cetara'),
            'options'  => array(
                '1' => esc_html__('On', 'cetara'),
                '0' => esc_html__('Off', 'cetara'),
            ),
            'default'  => '1'
        ),
        array(
            'id'       => 'single_author_book_heading_title',
            'type'     => 'text',
            'title'    => esc_html__('Heading', 'cetara'),
            'subtitle' => esc_html__('Enter your text', 'cetara'),
            'default'  => 'Author\'s books',
            'required'      => ['single_author_book', '!=', '0'],
        ),
    )
));
//Redux::setSection($opt_name, cetara_sidebar_opts());
/* 404 Page /--------------------------------------------------------- */
Redux::setSection($opt_name, array(
    'title'      => esc_html__('404 Page', 'cetara'),
    'icon'       => 'el-cog-alt el',
    'subsection' => true,
    'fields'     => array(
        array(
            'id'       => 'img_404_page',
            'type'     => 'media',
            'title'    => esc_html__('Image', 'cetara'),
            'default' => array()
        ),
        array(
            'id'       => 'heading_404_page',
            'type'     => 'text',
            'title'    => esc_html__('Heading', 'cetara'),
            'subtitle' => esc_html__('Enter your text', 'cetara'),
            'desc'     => esc_html__('Leave blank to use default text', 'cetara'),
            'default'  => '',
        ),
        array(
            'id'       => 'subheading_404_page',
            'type'     => 'text',
            'title'    => esc_html__('SubHeading', 'cetara'),
            'subtitle' => esc_html__('Enter your text', 'cetara'),
            'desc'     => esc_html__('Leave blank to use default text', 'cetara'),
            'default'  => '',
        ),
        array(
            'id'       => 'content_404_page',
            'type'     => 'textarea',
            'title'    => esc_html__('Content', 'cetara'),
            'subtitle' => esc_html__('Enter your text', 'cetara'),
            'desc'     => esc_html__('Leave blank to use default text', 'cetara'),
            'default' => '',
        ),
        array(
            'id'       => 'btn_text_404_page',
            'type'     => 'text',
            'title'    => esc_html__('Button Text', 'cetara'),
            'subtitle' => esc_html__('Enter your text', 'cetara'),
            'default'  => '',
            'desc'     => esc_html__('Leave blank to use default text', 'cetara')
        ),
        array(
            'id'               => 'bg_404_page',
            'type'             => 'background',
            'title'            => esc_html__('Background', 'cetara'),
            'subtitle'         => esc_html__('Choose your Background', 'cetara'),
            'desc'             => esc_html__('Leave blank to use default background', 'cetara'),
            'background-color' => false,
            'output'           => 'body.error404 .kng-main'
        ),
    ),
));

/*--------------------------------------------------------------
# Shop
--------------------------------------------------------------*/
if(class_exists('Woocommerce')) {
    Redux::setSection($opt_name, array(
        'title'  => esc_html__('Shop', 'cetara'),
        'icon'   => 'el el-shopping-cart',
        'fields' => array_merge(
            cetara_page_title_opts_fields([
                'prefix'         => 'shop_',
                'default_layout' => '9',
            ]),
            array(
                cetara_sidebar_opts([
                    'name'          => 'product_page_sidebar_pos',
                    'fields_only'   =>  true,
                    'default_value' => cetara_configs('blog')['single_sidebar_pos']  
                ]),
                array(
                    'id'            => 'product_page_content_col',
                    'title'         => esc_html__('Content Columns', 'cetara'),
                    'subtitle'      => esc_html__('Choose content Columns', 'cetara'),
                    'type'          => 'slider',
                    'default'       => cetara_configs('blog')['archive_content_col'],
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 11,
                    'display_value' => 'label',
                    'required'      => [ 
                        ['product_page_sidebar_pos', '!=', '0'],
                        ['product_page_sidebar_pos', '!=', 'bottom']
                    ],
                ),
                array(
                    'title'         => esc_html__('Products displayed per row', 'cetara'),
                    'id'            => 'products_columns',
                    'type'          => 'slider',
                    'subtitle'      => esc_html__('Number product to show per row', 'cetara'),
                    'default'       => 3,
                    'min'           => 2,
                    'step'          => 1,
                    'max'           => 6,
                    'display_value' => 'text'
                ),
                array(
                    'title'         => esc_html__('Products displayed per page', 'cetara'),
                    'id'            => 'product_per_page',
                    'type'          => 'slider',
                    'subtitle'      => esc_html__('Number product to show', 'cetara'),
                    'default'       => 9,
                    'min'           => 3,
                    'step'          => 1,
                    'max'           => 50,
                    'display_value' => 'text'
                ), 
            )
        )
    ));
    Redux::setSection($opt_name, array(
        'title'      => esc_html__('Single Products', 'cetara'),
        'icon'       => 'el el-shopping-cart',
        'subsection' => true,
        'fields'     => array_merge(
            cetara_page_title_opts_fields([
                'prefix'         => 'product_',
                'default_layout' => cetara_configs('product_ptitle')['layout'],
            ]),
            array(
                cetara_sidebar_opts([
                    'name'          => 'product_single_sidebar_pos',
                    'fields_only'   =>  true,
                    'default_value' => cetara_configs('blog')['single_sidebar_pos']  
                ]),
                array(
                    'id'            => 'product_single_content_col',
                    'title'         => esc_html__('Content Columns', 'cetara'),
                    'subtitle'      => esc_html__('Choose content Columns', 'cetara'),
                    'type'          => 'slider',
                    'default'       => cetara_configs('blog')['archive_content_col'],
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 11,
                    'display_value' => 'label',
                    'required'      => [ 
                        ['product_single_sidebar_pos', '!=', '0'],
                        ['product_single_sidebar_pos', '!=', 'bottom']
                    ],
                ),
                array(
                    'id'       => 'product_layout',
                    'type'     => 'button_set',
                    'title'    => esc_html__('Product Layout', 'cetara'),
                    'subtitle' => esc_html__('Select single product layout', 'cetara'),
                    'options' => array(
                        'default'  => esc_html__('Default', 'cetara'),
                        '1' => esc_html__('Layout 1', 'cetara')
                    ), 
                    'default' => 'default'
                ),
                array(
                    'id'       => 'product_image_cropped',
                    'title'    => esc_html__('Image Cropped', 'cetara'),
                    'subtitle' => esc_html__('Crop image for thumbnail, single, gallery', 'cetara'),
                    'type'     => 'switch',
                    'default'  => '1',
                ),
                array(
                    'id'       => 'product_variation_style',
                    'type'     => 'button_set',
                    'title'    => esc_html__('Product Variation Style', 'cetara'),
                    'subtitle' => esc_html__('Dropdown or selected list', 'cetara'),
                    'options' => array(
                        'dropdown'  => esc_html__('Dropdown', 'cetara'),
                        'list' => esc_html__('List', 'cetara')
                    ), 
                    'default' => 'dropdown'
                ),
                array(
                    'id'       => 'product_social_share_on',
                    'title'    => esc_html__('Social Share', 'cetara'),
                    'subtitle' => esc_html__('Show social share on single product.', 'cetara'),
                    'type'     => 'switch',
                    'default'  => '0',
                ),
                array(
                    'id'       => 'product_social_share_icon',
                    'type'     => 'button_set',
                    'title'    => esc_html__('Social Share', 'cetara'),
                    'subtitle' => esc_html__('Show social share on single post.', 'cetara'),
                    'multi'    => true,
                    'options' => array(
                        'facebook'  => esc_html__('Facebook', 'cetara'),
                        'instagram' => esc_html__('Instagram', 'cetara'),
                        'twitter'   => esc_html__('Twitter', 'cetara'),
                        'linkedin'  => esc_html__('Linkedin', 'cetara'),
                        'pinterest' => esc_html__('Pinterest', 'cetara'),
                        'google'    => esc_html__('Google Plus', 'cetara')
                    ), 
                    'default' => array('facebook', 'instagram', 'twitter', 'linkedin', 'google'),
                    'required' => [
                       'product_social_share_on',
                       'equals',
                       '1' 
                    ]
                ),
                // UpSells Product
                array(
                    'id'       => 'product_upsell',
                    'title'    => esc_html__('Up-Sells Product', 'cetara'),
                    'subtitle' => esc_html__('Show/Hide Up-Sells product', 'cetara'),
                    'type'     => 'switch',
                    'default'  => '1',
                ),
                array(
                    'id'            => 'product_upsell_total',
                    'title'         => esc_html__('Up-Sells Total', 'cetara'),
                    'subtitle'      => esc_html__('Total Up-Sells product display', 'cetara'),
                    'type'          => 'slider',
                    'default'       => '4',
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 12,
                    'display_value' => 'label',
                    'required' => [
                        ['product_upsell', '!=', '0'],
                    ]
                ),
                array(
                    'id'            => 'product_upsell_column',
                    'title'         => esc_html__('Up-Sells Columns', 'cetara'),
                    'subtitle'      => esc_html__('Choose your Columns', 'cetara'),
                    'type'          => 'slider',
                    'default'       => '4',
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 6,
                    'display_value' => 'label',
                    'required' => [
                        ['product_upsell', '!=', '0'],
                    ]
                ),
                // Related Product
                array(
                    'id'       => 'product_related',
                    'title'    => esc_html__('Product Related', 'cetara'),
                    'subtitle' => esc_html__('Show/Hide related product', 'cetara'),
                    'type'     => 'switch',
                    'default'  => '1',
                ),
                array(
                    'id'            => 'product_related_total',
                    'title'         => esc_html__('Related Total', 'cetara'),
                    'subtitle'      => esc_html__('Total related product display', 'cetara'),
                    'type'          => 'slider',
                    'default'       => '4',
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 12,
                    'display_value' => 'label',
                    'required' => [
                        ['product_related', '!=', '0'],
                    ]
                ),
                array(
                    'id'            => 'product_related_column',
                    'title'         => esc_html__('Related Columns', 'cetara'),
                    'subtitle'      => esc_html__('Choose your Columns', 'cetara'),
                    'type'          => 'slider',
                    'default'       => '4',
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 6,
                    'display_value' => 'label',
                    'required' => [
                        ['product_related', '!=', '0'],
                    ]
                )
            ),
            cetara_product_single_opts_wishlist_compare()
        )
    ));
    Redux::setSection($opt_name, array(
        'title'      => esc_html__('Cart Page', 'cetara'),
        'icon'       => 'el el-shopping-cart',
        'subsection' => true,
        'fields'     => array_merge(
            array(
                array(
                    'id'       => 'cart_cross_sell',
                    'title'    => esc_html__('Cross Sells', 'cetara'),
                    'subtitle' => esc_html__('Show/Hide Cross Sells product', 'cetara'),
                    'type'     => 'switch',
                    'default'  => '1',
                ),
                array(
                    'id'            => 'cart_cross_sell_total',
                    'title'         => esc_html__('Cross Sells Total', 'cetara'),
                    'subtitle'      => esc_html__('Total cross sell product display', 'cetara'),
                    'type'          => 'slider',
                    'default'       => '4',
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 12,
                    'display_value' => 'label',
                    'required' => [
                        ['cart_cross_sell', '!=', '0'],
                    ]
                ),
                array(
                    'id'            => 'cart_cross_sell_column',
                    'title'         => esc_html__('Cross Sells Columns', 'cetara'),
                    'subtitle'      => esc_html__('Choose your Columns', 'cetara'),
                    'type'          => 'slider',
                    'default'       => '4',
                    'min'           => 1,
                    'step'          => 1,
                    'max'           => 6,
                    'display_value' => 'label',
                    'required' => [
                        ['cart_cross_sell', '!=', '0'],
                    ]
                )
            )
        )
    ));
}

/*--------------------------------------------------------------
# Footer
--------------------------------------------------------------*/
Redux::setSection($opt_name, cetara_footer_opts());
 