<?php 
defined( 'ABSPATH' ) or exit( -1 );

/**
 * Author widgets
 *
 */

if(!function_exists('kng_register_wp_widget')) return;
add_action( 'widgets_init', function(){
    kng_register_wp_widget( 'KNG_Author_Product_Widget' );
});

class KNG_Author_Product_Widget extends WP_Widget
{
    function __construct()
    {
        parent::__construct(
            'kng_author_product',
            esc_html__( '*KNG Author Product', 'cetara' ),
            array(
                'description' => esc_attr__( 'Shows authors in products.', 'cetara' ),
                'customize_selective_refresh' => true,
            )
        );
    }

    /**
     * Outputs the HTML for this widget.
     *
     * @param array $args An array of standard parameters for widgets in this theme
     * @param array $instance An array of settings for this widget instance
     * @return void Echoes it's output
     **/
    function widget( $args, $instance ){
        global $wpdb;
        $instance = wp_parse_args( (array) $instance, array(
            'title'     => ''
        ) );
        $permalink_structure = get_option( 'permalink_structure', '' );
        $title = empty( $instance['title'] ) ? '' : $instance['title'];
        $title = apply_filters( 'widget_title', $title, $instance, $this->id_base );

        printf( '%s', $args['before_widget']);

        if(!empty($title)){
            printf( '%s %s %s', $args['before_title'] , $title , $args['after_title']);
        }
         
        $sql = "SELECT count(post_id) as count, meta_value as author_slug FROM {$wpdb->prefix}postmeta WHERE meta_key = 'product_author' group by meta_value";
        $results = $wpdb->get_results($sql, OBJECT);
        $list_results = array();
        foreach ($results as $re) {
            $count = $re->count;
            $author_slug = $re->author_slug;
            $author_id = cetara_get_id_by_slug($author_slug,'authors');
            $author = get_post($author_id);
            $list_results[] = [
                'author_id'     => $author->ID,
                'author_name'   => $author->post_title,
                'author_slug'   => $author_slug,
                'product_count' => $count
            ];
        }
 

        if ( !empty($list_results) ){

            echo '<div class="kng-authors-list">';
            echo '<ul class="kng-author-item kng-list-item">';
            foreach ($list_results as $result) {
                 
                if(empty($permalink_structure))
                    $link = home_url('/').'?post_type=product';
                else
                    $link = get_permalink( wc_get_page_id( 'shop' ) );

                $link = add_query_arg( 'au', rawurlencode($result['author_slug']), $link );

                echo '<li class="kng-author-item kng-list-item">';
                    echo '<a href="'.esc_url( $link ).'">';
                        echo '<span class="title">'.$result['author_name'].'</span>';
                        echo '<span class="count">'.$result['product_count'].'</span>';
                    echo '</a>';
                echo '</li>';
            }
            echo '</ul>';
            echo '</div>';
        }else{
            echo '<p class="not-found">'.esc_html__( 'No author found here','cetara' ).'</p>';
        }
        
        printf('%s', $args['after_widget']);
    }

    /**
     * Deals with the settings when they are saved by the admin. Here is
     * where any validation should be dealt with.
     *
     * @param array $new_instance An array of new settings as submitted by the admin
     * @param array $old_instance An array of the previous settings
     * @return array The validated and (if necessary) amended settings
     **/
    function update( $new_instance, $old_instance ){
        $instance              = $old_instance;
        $instance['title']     = sanitize_text_field( $new_instance['title'] );
        return $instance;
    }

    /**
     * Displays the form for this widget on the Widgets page of the WP Admin area.
     *
     * @param array $instance An array of the current settings for this widget
     * @return void Echoes it's output
     **/
    function form( $instance ){
        $instance = wp_parse_args( (array) $instance, array(
            'title'         => esc_html__( 'Author', 'cetara' ),
        ) );

        $title     = $instance['title'] ? esc_attr( $instance['title'] ) : esc_html__( 'Author', 'cetara' ); 
        ?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_html_e( 'Title:', 'cetara' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>" name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text" value="<?php echo esc_attr( $title ); ?>" />
        </p>
          
        <?php
    }
}
